==> intel-compute-runtime_21.32.20609.orig.tar.gz: compute-runtime-21.32.20609/shared/source/utilities/software_tags.h <==
/*
 * Copyright (C) 2021 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/helpers/string.h"

#include <sstream>
#include <string>

namespace NEO {
namespace SWTags {

enum class OpCode : uint32_t {
    Unknown,
    KernelName,
    PipeControlReason
};

enum class Component : uint32_t {
    COMMON = 1
};

struct BXMLHeapInfo {
    const uint32_t magicNumber = 0xDEB06D0C;
    const uint32_t heapSize;
    const uint32_t component = static_cast<uint32_t>(Component::COMMON);

    BXMLHeapInfo(size_t size) : heapSize(static_cast<uint32_t>(size)) {}

    static void bxml(std::ostream &os);
};

struct SWTagHeapInfo {
    const uint32_t magicNumber = 0xDEB06DD1;
    const uint32_t heapSize;
    const uint32_t component = static_cast<uint32_t>(Component::COMMON);

    SWTagHeapInfo(size_t size) : heapSize(static_cast<uint32_t>(size)) {}

    static void bxml(std::ostream &os);
};

struct BaseTag {
  public:
    BaseTag(OpCode code, size_t size) : opcode(static_cast<uint32_t>(code)),
                                        reserved(0),
                                        component(static_cast<uint32_t>(Component::COMMON)),
                                        driverDebug(1),
                                        DWORDCount(static_cast<uint32_t>(size / sizeof(uint32_t) - 2)) {}

    OpCode getOpCode() const { return static_cast<OpCode>(opcode); }
    static uint32_t getMarkerNoopID(OpCode opcode);
    static uint32_t getOffsetNoopID(uint32_t offset);
    static void bxml(std::ostream &os, OpCode opcode, size_t size, const char *name);

  protected:
    union MarkerNoopID {
        struct {
            uint32_t OpCode : 20;
            uint32_t Reserved : 12;
        };
        uint32_t value;
    };
    union OffsetNoopID {
        struct {
            uint32_t Offset : 20;
            uint32_t SubTag : 1;
            uint32_t MagicBit : 1;
            uint32_t Reserved : 10;
        };
        uint32_t value;
    };

    const uint32_t opcode : 20;
    const uint32_t reserved : 4;
    const uint32_t component : 7;
    const uint32_t driverDebug : 1; // always 0x1
    const uint32_t DWORDCount;
};

struct KernelNameTag : public BaseTag {
  public:
    KernelNameTag(const char *name)
        : BaseTag(OpCode::KernelName, sizeof(KernelNameTag)) {
        strcpy_s(kernelName, KENEL_NAME_STR_LENGTH, name);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int KENEL_NAME_STR_LENGTH = sizeof(uint32_t) * 16; // Dword aligned
    char kernelName[KENEL_NAME_STR_LENGTH] = {};
};

struct PipeControlReasonTag : public BaseTag {
  public:
    PipeControlReasonTag(const char *reason)
        : BaseTag(OpCode::PipeControlReason, sizeof(PipeControlReasonTag)) {
        strcpy_s(reasonString, REASON_STR_LENGTH, reason);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int REASON_STR_LENGTH = sizeof(uint32_t) * 32; // Dword aligned
    char reasonString[REASON_STR_LENGTH] = {};
};

struct SWTagBXML {
    SWTagBXML();

    std::string str;
};

} // namespace SWTags
} // namespace NEO

==> intel-compute-runtime_22.14.22890.orig.tar.gz: compute-runtime-22.14.22890/shared/source/utilities/software_tags.h <==
/*
 * Copyright (C) 2021 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/helpers/string.h"

#include <sstream>
#include <string>

namespace NEO {
namespace SWTags {

enum class OpCode : uint32_t {
    Unknown,
    KernelName,
    PipeControlReason,
    CallNameBegin,
    CallNameEnd
};

enum class Component : uint32_t {
    COMMON = 1
};

struct BXMLHeapInfo {
    const uint32_t magicNumber = 0xDEB06D0C;
    const uint32_t heapSize;
    const uint32_t component = static_cast<uint32_t>(Component::COMMON);

    BXMLHeapInfo(size_t size) : heapSize(static_cast<uint32_t>(size)) {}

    static void bxml(std::ostream &os);
};

struct SWTagHeapInfo {
    const uint32_t magicNumber = 0xDEB06DD1;
    const uint32_t heapSize;
    const uint32_t component = static_cast<uint32_t>(Component::COMMON);

    SWTagHeapInfo(size_t size) : heapSize(static_cast<uint32_t>(size)) {}

    static void bxml(std::ostream &os);
};

struct BaseTag {
  public:
    BaseTag(OpCode code, size_t size) : opcode(static_cast<uint32_t>(code)),
                                        reserved(0),
                                        component(static_cast<uint32_t>(Component::COMMON)),
                                        driverDebug(1),
                                        DWORDCount(static_cast<uint32_t>(size / sizeof(uint32_t) - 2)) {}

    OpCode getOpCode() const { return static_cast<OpCode>(opcode); }
    static uint32_t getMarkerNoopID(OpCode opcode);
    static uint32_t getOffsetNoopID(uint32_t offset);
    static void bxml(std::ostream &os, OpCode opcode, size_t size, const char *name);

  protected:
    union MarkerNoopID {
        struct {
            uint32_t OpCode : 20;
            uint32_t Reserved : 12;
        };
        uint32_t value;
    };
    union OffsetNoopID {
        struct {
            uint32_t Offset : 20;
            uint32_t SubTag : 1;
            uint32_t MagicBit : 1;
            uint32_t Reserved : 10;
        };
        uint32_t value;
    };

    const uint32_t opcode : 20;
    const uint32_t reserved : 4;
    const uint32_t component : 7;
    const uint32_t driverDebug : 1; // always 0x1
    const uint32_t DWORDCount;
};

struct KernelNameTag : public BaseTag {
  public:
    KernelNameTag(const char *name, uint32_t callId)
        : BaseTag(OpCode::KernelName, sizeof(KernelNameTag)) {
        strcpy_s(kernelName, KENEL_NAME_STR_LENGTH, name);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int KENEL_NAME_STR_LENGTH = sizeof(uint32_t) * 16; // Dword aligned
    char kernelName[KENEL_NAME_STR_LENGTH] = {};
};

struct PipeControlReasonTag : public BaseTag {
  public:
    PipeControlReasonTag(const char *reason, uint32_t callId)
        : BaseTag(OpCode::PipeControlReason, sizeof(PipeControlReasonTag)) {
        strcpy_s(reasonString, REASON_STR_LENGTH, reason);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int REASON_STR_LENGTH = sizeof(uint32_t) * 32; // Dword aligned
    char reasonString[REASON_STR_LENGTH] = {};
};

struct CallNameBeginTag : public BaseTag {
  public:
    CallNameBeginTag(const char *name, uint32_t callId)
        : BaseTag(OpCode::CallNameBegin, sizeof(CallNameBeginTag)) {
        strcpy_s(zeCallName, ZE_CALL_NAME_STR_LENGTH, name);
        snprintf(zeCallId, sizeof(uint32_t), "%x", callId);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int ZE_CALL_NAME_STR_LENGTH = sizeof(uint32_t) * 32; // Dword aligned
    char zeCallName[ZE_CALL_NAME_STR_LENGTH] = {};
    char zeCallId[ZE_CALL_NAME_STR_LENGTH] = {};
};

struct CallNameEndTag : public BaseTag {
  public:
    CallNameEndTag(const char *name, uint32_t callId)
        : BaseTag(OpCode::CallNameEnd, sizeof(CallNameEndTag)) {
        strcpy_s(zeCallName, ZE_CALL_NAME_STR_LENGTH, name);
        snprintf(zeCallId, sizeof(uint32_t), "%x", callId);
    }

    static void bxml(std::ostream &os);

  private:
    static constexpr unsigned int ZE_CALL_NAME_STR_LENGTH = sizeof(uint32_t) * 32; // Dword aligned
    char zeCallName[ZE_CALL_NAME_STR_LENGTH] = {};
    char zeCallId[ZE_CALL_NAME_STR_LENGTH] = {};
};

struct SWTagBXML {
    SWTagBXML();

    std::string str;
};

} // namespace SWTags
} // namespace NEO
